#!/usr/bin/env python
# coding: utf-8
import subprocess
import numpy as np
import sympy as sp
import pystencils as ps
from pystencils_benchmark import generate_benchmark
from pathlib import Path


def generate(path: Path):
    a, b, c = ps.fields(a=np.ones(4000000), b=np.ones(4000000), c=np.ones(4000000))
    alpha = sp.symbols('alpha')

    @ps.kernel_config(ps.CreateKernelConfig())
    def vadd():
        a[0] @= b[0] + c[0]
    kernel_vadd = ps.create_kernel(**vadd)

    @ps.kernel_config(ps.CreateKernelConfig())
    def daxpy():
        b[0] @= alpha * a[0] + b[0]
    kernel_daxpy = ps.create_kernel(**daxpy)

    generate_benchmark([kernel_vadd, kernel_daxpy], path)


def make(path: Path):
    subprocess.run(['make'])


def execute(path: Path):
    subprocess.run(['./benchmark-GCC', '200'])


def main():
    path = Path.cwd()
    generate(path)
    make(path)
    execute(path)


if __name__ == '__main__':
    main()

